@@ -39,4 +39,7 @@ class HACModel(nn.Module):
         x = self.drop_layer(x)
         x = self.fcn(x).squeeze()
         #x = self.relu(x)
-        return x
\ No newline at end of file
+        return x
+
+    def get_num_vertices(self):
+        return self.graph.get_num_vertices()
\ No newline at end of file
